| ma | R Documentation |
Function to calculate the moving average of a given numeric vector. The order of the moving average may be customized by the user (man argument).
ma(data, man = 10, warnings = FALSE)
data |
A |
man |
An |
warnings |
A |
This function returns a vector with the moving average of the input data.
data("munich_pollen")
ma(data = munich_pollen$Betula, man = 10, warnings = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.