| plot_ps | R Documentation |
Function to plot the main pollen season of a single pollen type.
plot_ps(
data,
pollen.type = NULL,
year = NULL,
days = 30,
fill.col = "turquoise4",
int.method = "lineal",
axisname = expression(paste("Pollen grains / m"^"3")),
...
)
data |
A |
pollen.type |
A |
year |
A |
days |
A |
fill.col |
A |
int.method |
A |
axisname |
A |
... |
Other arguments passed on to the pollen season calculation as specified in |
plot_ps function is designed to easily plot the main pollen season (Galan et al., 2017). The pre_peak period and the post_peak period are marked with different color intensity in the graph. The user must choose a single pollen type and season to plot.
The function returns an object of class ggplot with a graphical representation of the main pollen season of the selected pollen type. The pre_peak and post_peak periods are marked with different color intensity.
Galan, C., Ariatti, A., Bonini, M., Clot, B., Crouzy, B., Dahl, A., Fernandez_Gonzalez, D., Frenguelli, G., Gehrig, R., Isard, S., Levetin, E., Li, D.W., Mandrioli, P., Rogers, C.A., Thibaudon, M., Sauliene, I., Skjoth, C., Smith, M., Sofiev, M., 2017. Recommended terminology for aerobiological studies. Aerobiologia (Bologna). 293_295.
calculate_ps, interpollen, ggplot.
data("munich_pollen")
plot_ps(munich_pollen, year = 2013, pollen.type = "Betula")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.