| plot_trend | R Documentation |
Function to calculate the main seasonal indexes of the pollen season (Start Date, Peak Date, End Date and Pollen Integral). Trends analysis of the parameters over the seasons. Plots showing the distribution of the main seasonal indexes over the years.
plot_trend(
data,
base_dir = getwd(),
table_dir = file.path(base_dir, "table_AeRobiology"),
interpolation = TRUE,
int.method = "lineal",
export.plot = TRUE,
export.format = "pdf",
export.result = TRUE,
method = "percentage",
...
)
data |
A |
base_dir |
Character. Base directory where output tables are stored. |
table_dir |
Character. Directory where tables are exported. |
interpolation |
A |
int.method |
A |
export.plot |
A |
export.format |
A |
export.result |
A |
method |
A |
... |
Additional arguments for the function |
This function returns several plots in the directory plot_AeRobiology/trend_plots with the extension .pdf or .png.Also produces an object of the class data.frame and export a table with the extension .xlsx, in the directory table_AeRobiology.
These tables have the information about the slope (beta coefficient of a lineal model using as predictor the year and as dependent variable one of the main pollen season indexes). The information is referred to the main pollen season indexes: Start Date, Peak Date, End Date and Pollen Integral.
calculate_ps; analyse_trend
data("munich_pollen")
plot_trend(munich_pollen, interpolation = FALSE, export.plot = FALSE, export.result = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.