View source: R/plot_monthly_heatmap.R
| plot_monthly_heatmap | R Documentation |
Function to plot monthly sums of daily pollen concentrations as a heatmap. Months are displayed in the x axis and years in the y axis for one selected pollen type.
plot_monthly_heatmap(
data,
pollen.type,
location = NULL,
location.col = NULL,
start.month = 1,
color.A = "yellow",
color.B = "red",
result = "plot"
)
data |
A |
pollen.type |
A |
location |
A |
location.col |
A |
start.month |
A |
color.A |
A |
color.B |
A |
result |
A |
If result == "plot", the function returns an object of class
ggplot2; if result == "table", the function returns a
data.frame with the monthly sums.
data("munich_pollen")
plot_monthly_heatmap(munich_pollen, pollen.type = "Betula")
plot_monthly_heatmap(munich_pollen, pollen.type = "Poaceae", start.month = 6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.